@@ -4,7 +4,7 @@
 /* Simple test to ensure that we can load the xapian module and exercise basic
  * functionality successfully.
  *
- * Copyright (C) 2004,2005,2006,2007,2009,2011,2012,2013,2014,2015,2016,2017,2019 Olly Betts
+ * Copyright (C) 2004-2022 Olly Betts
  * Copyright (C) 2010 Richard Boulton
  *
  * This program is free software; you can redistribute it and/or
@@ -334,13 +334,18 @@ class testfieldprocessor extends XapianFieldProcessor {
     }
 }
 
-$tfp = new testfieldprocessor();
-$qp->add_prefix('spam', $tfp);
+$qp->add_prefix('spam', new testfieldprocessor);
+$qp->add_boolean_prefix('filter', new testfieldprocessor);
 $query = $qp->parse_query('spam:ignored');
 if ($query->get_description() !== 'Query(spam)') {
     print "testfieldprocessor didn't work - result was ".$query->get_description()."\n";
     exit(1);
 }
+$query = $qp->parse_query('filter:ignored');
+if ($query->get_description() !== 'Query(0 * spam)') {
+    print "Boolean testfieldprocessor didn't work - result was ".$query->get_description()."\n";
+    exit(1);
+}
 
 try {
     $query = $qp->parse_query('spam:spam');
@@ -459,12 +464,12 @@ $enquire->set_query(new XapianQuery("foo"));
 	exit(1);
     }
 
-    $mset = $enquire->get_mset(0, 10, 0, null, $md, null);
+    $mset = $enquire->get_mset(0, 10, 0, null, $md);
     mset_expect_order($mset, array(2));
 
     $md = new XapianValueSetMatchDecider(0, false);
     $md->add_value("ABC");
-    $mset = $enquire->get_mset(0, 10, 0, null, $md, null);
+    $mset = $enquire->get_mset(0, 10, 0, null, $md);
     mset_expect_order($mset, array(1, 3, 4, 5));
 }
 
@@ -583,6 +588,16 @@ if ($s !== 'ask:1 i:1 in:2 nothing:1 return:2 tea:1 time:2 ') {
     exit(1);
 }
 
+// Test that XapianTermGenerator keeps a reference to XapianStopper.
+$indexer->set_stopper_strategy(XapianTermGenerator::STOP_ALL);
+{
+    $stop = new XapianSimpleStopper();
+    $stop->add('a');
+    $indexer->set_stopper($stop);
+    $stop = null;
+}
+$indexer->index_text("a b");
+
 # Test GeoSpatial API
 $coord = new XapianLatLongCoord();
 $coord = new XapianLatLongCoord(-41.288889, 174.777222);
@@ -608,6 +623,9 @@ $centre->append(new XapianLatLongCoord(40.6048, -74.4427));
 $ps = new XapianLatLongDistancePostingSource(COORD_SLOT, $centre, $metric, $range);
 $q = new XapianQuery("coffee");
 $q = new XapianQuery(XapianQuery::OP_AND, $q, new XapianQuery($ps));
+$q = new XapianQuery(XapianQuery::OP_OR, [$q, XapianQuery::MatchNothing()]);
+// Check that we keep a reference via XapianQuery.
+$ps = null;
 
 $enq = new XapianEnquire($db);
 $enq->set_query($q);
@@ -633,6 +651,8 @@ $qp = new XapianQueryParser();
     $stop = new XapianSimpleStopper();
     $stop->add('a');
     $qp->set_stopper($stop);
+    // Test that XapianQueryParser keeps a reference to XapianStopper.
+    $stop = null;
 }
 $query = $qp->parse_query('a b');
 if ($query->get_description() !== 'Query(b@2)') {
